﻿using System;
using Android.App;
using Android.Content;
using Android.Widget;
using Android.OS;
using System.IO;
using Android.Provider;
using Android.Webkit;

namespace PDFFormTesting
{
	[Activity(Label = "PDFFormTesting", MainLauncher = true, Icon = "@drawable/icon")]
	public class MainActivity : Activity
	{
		public string ImageDirectory => Android.OS.Environment.GetExternalStoragePublicDirectory(Android.OS.Environment.DirectoryPictures).AbsolutePath;
		private string TemporaryPhotoFilePath => ImageDirectory + "/TempFileForPhoto.jpg";

		protected override void OnCreate(Bundle bundle)
		{
			base.OnCreate(bundle);
			SetContentView(Resource.Layout.Main);
			var button = FindViewById<Button>(Resource.Id.MyButton);
			button.Click += (sender, args) => TakePicture();
		}

		void TakePicture()
		{
			var temporaryPhotoFilePath = TemporaryPhotoFilePath;
			var intent = new Intent(MediaStore.ActionImageCapture);
			intent.PutExtra(MediaStore.ExtraOutput, Android.Net.Uri.FromFile(new Java.IO.File(temporaryPhotoFilePath)));
			StartActivityForResult(intent, 0);
		}


		protected override void OnActivityResult(int requestCode, Result resultCode, Intent data)
		{
			base.OnActivityResult(requestCode, resultCode, data);
			var outputPath = GeneratePdf();
			ViewPdf(outputPath);
		}

		private string GeneratePdf()
		{
			var id = Guid.NewGuid();
			var imagePath = ImageDirectory + $"/{id}.jpg";
			var pdfPath = ImageDirectory + $"/{id}.pdf";

			File.Move(TemporaryPhotoFilePath, imagePath);

			var assembler = new DocumentAssembler(new[] {imagePath}, ImageDirectory, $"{id}.pdf");
			assembler.AssembleDocumentAsPortableDocumentFormat();
			return pdfPath;
		}

		private void ViewPdf(string outputPath)
		{
			var intent = new Intent(Intent.ActionView);
			var extension = Path.GetExtension(outputPath)?.Substring(1);
			var mimeType = MimeTypeMap.Singleton.GetMimeTypeFromExtension(extension);
			intent.SetDataAndType(Android.Net.Uri.FromFile(new Java.IO.File(outputPath)), mimeType);
			intent.SetFlags (ActivityFlags.ClearWhenTaskReset | ActivityFlags.NewTask);
			intent.AddFlags (ActivityFlags.GrantReadUriPermission);
			StartActivity(intent);
		}
	}
}
